Class: Fixnum
- Inherits:
-
Object
- Object
- Fixnum
- Defined in:
- lib/standard/int.rb
Overview
Copyright 2014 Maxine Red <[email protected]>
This file is part of rubyhexagon.
rubyhexagon is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
rubyhexagon is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with rubyhexagon. If not, see <http://www.gnu.org/licenses/>.
Instance Method Summary collapse
Instance Method Details
#days ⇒ Object
29 30 31 |
# File 'lib/standard/int.rb', line 29 def days 60*60*24*self end |
#pad(c, s = 0) ⇒ Object
33 34 35 |
# File 'lib/standard/int.rb', line 33 def pad(c,s=0) "#{s}"*(c-self.to_s.length)+self.to_s end |
#to_kb ⇒ Object
21 22 23 |
# File 'lib/standard/int.rb', line 21 def to_kb (self/1024.0).round(2) end |
#to_mb ⇒ Object
25 26 27 |
# File 'lib/standard/int.rb', line 25 def to_mb (self/(1024*1024.0)).round(2) end |