Module: Rubyhexagon

Defined in:
lib/rubyhexagon.rb,
lib/rubyhexagon/tag.rb,
lib/rubyhexagon/pool.rb,
lib/rubyhexagon/post.rb,
lib/rubyhexagon/type.rb,
lib/rubyhexagon/user.rb,
lib/rubyhexagon/error.rb,
lib/rubyhexagon/image.rb,
lib/rubyhexagon/level.rb,
lib/rubyhexagon/login.rb,
lib/rubyhexagon/artist.rb,
lib/rubyhexagon/helper/api.rb,
lib/rubyhexagon/tag_change.rb,
lib/rubyhexagon/search/tags.rb,
lib/rubyhexagon/search/pools.rb,
lib/rubyhexagon/search/posts.rb,
lib/rubyhexagon/search/tag_history.rb,
lib/rubyhexagon/search/flag_history.rb

Overview

Copyright 2014-2018 Maxine Michalski [email protected]

This file is part of rubyhexagon.

rubyhexagon is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

rubyhexagon is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with rubyhexagon. If not, see http://www.gnu.org/licenses/.

Defined Under Namespace

Modules: Search Classes: API, AccessDenied, AlreadyFavorited, Artist, DeletedPost, Image, Level, Login, Pool, Post, Preview, Sample, Tag, TagChange, Type, User

Constant Summary collapse

MAJOR =

Since:

  • 0.4.3

1
MINOR =

Since:

  • 0.4.3

6
PATCH =

Since:

  • 0.4.3

2
NAME =

Since:

  • 0.4.3

'rubyhexagon'
VERSION =

Since:

  • 0.4.3

"#{MAJOR}.#{MINOR}.#{PATCH}"