Exception: Rubyhexagon::AlreadyFavorited
- Inherits:
-
StandardError
- Object
- StandardError
- Rubyhexagon::AlreadyFavorited
- Defined in:
- lib/rubyhexagon/error.rb
Overview
Error class to denote that a Post was already favorited.
Error class to denote that a Post was already favorited.